summaryrefslogtreecommitdiff
path: root/src/lv2_gui.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/lv2_gui.cc')
-rw-r--r--src/lv2_gui.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/lv2_gui.cc b/src/lv2_gui.cc
index 858e097..b474534 100644
--- a/src/lv2_gui.cc
+++ b/src/lv2_gui.cc
@@ -8,20 +8,20 @@
****************************************************************************/
/*
- * This file is part of DrumGizmo.
+ * This file is part of CamSync.
*
* DrumGizmo is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* DrumGizmo is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with DrumGizmo; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/
#include "lv2_gui.h"
@@ -37,7 +37,7 @@
// From: http://codesearch.google.com/#50sg5qT6WNE/src/lv2_ui_dssi.c
// git://repo.or.cz/nekobee.git/src/lv2_ui_dssi.c
-#define DRUMGIZMO_UI_URI "http://drumgizmo.org/lv2-gui"
+#define CAMSYNC_UI_URI "http://camsync.org/lv2-gui"
#include <plugingui.h>
@@ -111,7 +111,7 @@ struct DG_GUI {
LV2_Handle instance_handle;
LV2_Extension_Data_Feature *data_access;
- DrumGizmo *instance;
+ CamSync *instance;
LV2UI_Controller controller;
GUI::PluginGUI *gui;
@@ -183,8 +183,8 @@ static LV2UI_Handle ui_instantiate(const struct _LV2UI_Descriptor * descriptor,
features++;
}
- LV2_DrumGizmo_Descriptor *dgd =
- (LV2_DrumGizmo_Descriptor *)(*pt->data_access->data_access)(PLUGIN_INSTANCE_URI);
+ LV2_CamSync_Descriptor *dgd =
+ (LV2_CamSync_Descriptor *)(*pt->data_access->data_access)(PLUGIN_INSTANCE_URI);
pt->instance = dgd->get_pci(pt->instance_handle);
pt->virt.run = ui_run;
@@ -219,7 +219,7 @@ extern "C" {
#endif
static LV2UI_Descriptor descriptor = {
- DRUMGIZMO_UI_URI,
+ CAMSYNC_UI_URI,
ui_instantiate,
ui_cleanup,
ui_port_event,
@@ -8,20 +8,20 @@
*
- * DrumGizmo is free software; you can redistribute it and/or modify
+ * CamSync is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -8,20 +8,20 @@
* (at your option) any later version.
*
- * DrumGizmo is distributed in the hope that it will be useful,
+ * CamSync is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -8,20 +8,20 @@
*
* You should have received a copy of the GNU General Public License
- * along with DrumGizmo; if not, write to the Free Software
+ * along with CamSync; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/